@@ -1,10 +1,8 @@
-import os
 import cv2
 import numpy as np
-import glob
 import torch
 from torchvision.transforms.functional import normalize
-from basicsr.utils import imwrite, img2tensor, tensor2img
+from basicsr.utils import img2tensor, tensor2img
 from basicsr.utils.download_util import load_file_from_url
 from basicsr.utils.misc import gpu_is_available, get_device
 from facelib.utils.face_restoration_helper import FaceRestoreHelper
@@ -127,87 +125,33 @@ class CodeFormer:
             device=self.device,
         )
 
-    def restore(self):
-        # ------------------------ input & output ------------------------
+    def upscale(self, image):
+        # ----------------------- input & output -----------------------
         w = self.fidelity_weight
-        input_video = False
-        # input single img path
-        if self.input_path.endswith(("jpg", "jpeg", "png", "JPG", "JPEG", "PNG")):
-            input_img_list = [self.input_path]
-            result_root = f"results/test_img_{w}"
-        # input video path
-        elif self.input_path.endswith(("mp4", "mov", "avi", "MP4", "MOV", "AVI")):
-            from basicsr.utils.video_util import VideoReader, VideoWriter
+        img = cv2.cvtColor(np.array(image), cv2.COLOR_RGB2BGR)
 
-            input_img_list = []
-            vidreader = VideoReader(self.input_path)
-            image = vidreader.get_frame()
-            while image is not None:
-                input_img_list.append(image)
-                image = vidreader.get_frame()
-            audio = vidreader.get_audio()
-            fps = (
-                vidreader.get_fps()
-                if self.save_video_fps is None
-                else self.save_video_fps
+        # ------------------------ processing --------------------------
+        # clean all the intermediate results to process the next image
+        self.face_helper.clean_all()
+
+        if self.has_aligned:
+            # the input faces are already cropped and aligned
+            img = cv2.resize(img, (512, 512), interpolation=cv2.INTER_LINEAR)
+            self.face_helper.is_gray = is_gray(img, threshold=10)
+            if self.face_helper.is_gray:
+                print("Grayscale input: True")
+            self.face_helper.cropped_faces = [img]
+        else:
+            self.face_helper.read_image(img)
+            # get face landmarks for each face
+            num_det_faces = self.face_helper.get_face_landmarks_5(
+                only_center_face=self.only_center_face,
+                resize=640,
+                eye_dist_threshold=5,
             )
-            video_name = os.path.basename(self.input_path)[:-4]
-            result_root = f"results/{video_name}_{w}"
-            input_video = True
-            vidreader.close()
-        else:  # input img folder
-            if self.input_path.endswith("/"):  # solve when path ends with /
-                self.input_path = self.input_path[:-1]
-            # scan all the jpg and png images
-            input_img_list = sorted(
-                glob.glob(os.path.join(self.input_path, "*.[jpJP][pnPN]*[gG]"))
-            )
-            result_root = f"results/{os.path.basename(self.input_path)}_{w}"
-
-        if not self.output_path is None:  # set output path
-            result_root = self.output_path
-
-        test_img_num = len(input_img_list)
-        if test_img_num == 0:
-            raise FileNotFoundError(
-                "No input image/video is found...\n"
-                "\tNote that --input_path for video should end with .mp4|.mov|.avi"
-            )
-
-        # -------------------- start to processing ---------------------
-        for i, img_path in enumerate(input_img_list):
-            # clean all the intermediate results to process the next image
-            self.face_helper.clean_all()
-
-            if isinstance(img_path, str):
-                img_name = os.path.basename(img_path)
-                basename, ext = os.path.splitext(img_name)
-                # print(f"[{i+1}/{test_img_num}] Processing: {img_name}")
-                img = cv2.imread(img_path, cv2.IMREAD_COLOR)
-            else:  # for video processing
-                basename = str(i).zfill(6)
-                img_name = f"{video_name}_{basename}" if input_video else basename
-                # print(f"[{i+1}/{test_img_num}] Processing: {img_name}")
-                img = img_path
-
-            if self.has_aligned:
-                # the input faces are already cropped and aligned
-                img = cv2.resize(img, (512, 512), interpolation=cv2.INTER_LINEAR)
-                self.face_helper.is_gray = is_gray(img, threshold=10)
-                if self.face_helper.is_gray:
-                    print("Grayscale input: True")
-                self.face_helper.cropped_faces = [img]
-            else:
-                self.face_helper.read_image(img)
-                # get face landmarks for each face
-                num_det_faces = self.face_helper.get_face_landmarks_5(
-                    only_center_face=self.only_center_face,
-                    resize=640,
-                    eye_dist_threshold=5,
-                )
-                # print(f"\tdetect {num_det_faces} faces")
-                # align and warp each face
-                self.face_helper.align_warp_face()
+            # print(f"\tdetect {num_det_faces} faces")
+            # align and warp each face
+            self.face_helper.align_warp_face()
 
             # face restoration for each cropped face
             for idx, cropped_face in enumerate(self.face_helper.cropped_faces):
@@ -258,59 +202,6 @@ class CodeFormer:
                         upsample_img=bg_img, draw_box=self.draw_box
                     )
 
-            # # save faces
-            # for idx, (cropped_face, restored_face) in enumerate(
-            #     zip(self.face_helper.cropped_faces, self.face_helper.restored_faces)
-            # ):
-            #     # save cropped face
-            #     if not self.has_aligned:
-            #         save_crop_path = os.path.join(
-            #             result_root, "cropped_faces", f"{basename}_{idx:02d}.png"
-            #         )
-            #         imwrite(cropped_face, save_crop_path)
-            #     # save restored face
-            #     if self.has_aligned:
-            #         save_face_name = f"{basename}.png"
-            #     else:
-            #         save_face_name = f"{basename}_{idx:02d}.png"
-            #     if self.suffix is not None:
-            #         save_face_name = f"{save_face_name[:-4]}_{self.suffix}.png"
-            #     save_restore_path = os.path.join(
-            #         result_root, "restored_faces", save_face_name
-            #     )
-            #     imwrite(restored_face, save_restore_path)
-
-            # # save restored img
-            # if not self.has_aligned and restored_img is not None:
-            #     if self.suffix is not None:
-            #         basename = f"{basename}_{self.suffix}"
-            #     save_restore_path = os.path.join(
-            #         result_root, "final_results", f"{basename}.png"
-            #     )
-            #     imwrite(restored_img, save_restore_path)
-
-        # # save enhanced video
-        # if input_video:
-        #     print("Video Saving...")
-        #     # load images
-        #     video_frames = []
-        #     img_list = sorted(
-        #         glob.glob(os.path.join(result_root, "final_results", "*.[jp][pn]g"))
-        #     )
-        #     for img_path in img_list:
-        #         img = cv2.imread(img_path)
-        #         video_frames.append(img)
-        #     # write images to video
-        #     height, width = video_frames[0].shape[:2]
-        #     if self.suffix is not None:
-        #         video_name = f"{video_name}_{self.suffix}.png"
-        #     save_restore_path = os.path.join(result_root, f"{video_name}.mp4")
-        #     vidwriter = VideoWriter(save_restore_path, height, width, fps, audio)
-
-        #     for f in video_frames:
-        #         vidwriter.write_frame(f)
-        #     vidwriter.close()
-
         img_encode = cv2.imencode(".jpg", restored_img)[1]
 
         # Converting the image into numpy array
